@@ -13,12 +13,12 @@ LaTeX::Decode - Decode from LaTeX to Unicode
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
 use base qw(Exporter);
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our @EXPORT  = qw(latex_decode);
 use LaTeX::Decode::Data;
 use Unicode::Normalize;
@@ -42,7 +42,7 @@ Decodes the given text from LaTeX to Unicode.
 
 The function accepts a number of options:
 
-    * normalize => $bool (default 1)
+    * normalize => $bool (default 0)
         whether the output string should be normalized with Unicode::Normalize
 
     * normalization => <normalization form> (default 'NFC')
@@ -57,16 +57,16 @@ The function accepts a number of options:
 =head1 GLOBAL OPTIONS
 
 The decoding scheme can be set with
-
-    $LaTeX::Decode::DefaultScheme = '<name>';
-
+  $LaTeX::Decode::DefaultScheme = '<name>';
 Possible values are 'base', 'extra' and 'full'; default value is 'extra'.
 
+TODO : explain these scheme!
+
 base  => Most common macros and diacritics (sufficient for Western languages
          and common symbols)
 
-extra => Also converts punctuation, larger range of diacritics and macros
-         (e.g. for IPA, Latin Extended Additional, etc.)
+extra => Also converts punctuation, larger range of diacritics and macros (e.g. for IPA, Latin Extended
+         Additional, etc.)
 
 full  => Also converts symbols, Greek letters, dingbats, negated symbols, and
          superscript characters and symbols ...
@@ -189,7 +189,7 @@ I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2010 François Charette, all rights reserved.
+Copyright 2009-2015 François Charette, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
